==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/bibtexentryfield.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXENTRYFIELD_H
#define BIBTEXENTRYFIELD_H

#include <qobject.h>

#include <bibtexelement.h>

namespace BibTeX
{
    class BibTeXElement;

    class BibTeXEntryField : public QObject
    {
        Q_OBJECT
    public:
        enum FieldType {ftAbstract, ftAddress, ftAnnote, ftAuthor, ftBookTitle, ftChapter, ftCrossRef, ftEdition, ftEditor, ftHowPublished, ftInstitution, ftISBN, ftISSN, ftJournal, ftKey, ftMonth, ftNote, ftNumber, ftOrganization, ftPages, ftPublisher, ftSchool, ftSeries, ftTitle, ftType, ftURL, ftVolume, ftYear, ftUnknown};
        enum FieldRequireStatus {frsRequired, frsOptional, frsIgnored};

        BibTeXEntryField( FieldType fieldType );
        BibTeXEntryField( const QString &fieldTypeName );
        BibTeXEntryField( BibTeXEntryField* other );
        ~BibTeXEntryField();

        QString fieldTypeName();
        FieldType fieldType();

        void appendFieldItem( const BibTeX::BibTeXElement::FieldItem& fieldItem );
        void clearFieldItems();
        BibTeX::BibTeXElement::FieldItems::iterator begin();
        BibTeX::BibTeXElement::FieldItems::iterator end();

        static QString fieldTypeToString( const FieldType fieldType );
        static FieldType fieldTypeFromString( const QString &fieldTypeString );

    private:
        FieldType m_fieldType;
        QString m_fieldTypeName;
        BibTeXElement::FieldItems m_fieldItems;
    };

}

#endif

==> kbibtex-0.1.4.tar.bz2: kbibtex-0.1.4/src/bibtexentryfield.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXBIBTEXENTRYFIELD_H
#define BIBTEXBIBTEXENTRYFIELD_H

#include <qstring.h>

#include <bibtexvalue.h>

namespace BibTeX
{
    class BibTeXEntryField
    {
    public:
        enum FieldType {ftAbstract, ftAddress, ftAnnote, ftAuthor, ftBookTitle, ftChapter, ftCrossRef, ftDoi, ftEdition, ftEditor, ftHowPublished, ftInstitution, ftISBN, ftISSN, ftJournal, ftKey, ftLocation, ftMonth, ftNote, ftNumber, ftOrganization, ftPages, ftPublisher, ftSchool, ftSeries, ftTitle, ftType, ftURL, ftVolume, ftYear, ftUnknown};

        BibTeXEntryField( FieldType fieldType );
        BibTeXEntryField( const QString &fieldTypeName );
        BibTeXEntryField( BibTeX::BibTeXEntryField *other );
        ~BibTeXEntryField();

        QString fieldTypeName() const;
        FieldType fieldType() const;

        static QString fieldTypeToString( const FieldType fieldType );
        static FieldType fieldTypeFromString( const QString &fieldTypeString );

        BibTeX::BibTeXValue *value();
        void setValue( const BibTeX::BibTeXValue *value );

    private:
        FieldType m_fieldType;
        QString m_fieldTypeName;
        BibTeXValue *m_value;
    };

}

#endif
